tchart
======

Minimal chart renderer for fixed size canvas for Python3.


Installation
------------

``pip install tchart``


Bugs
----

Bugs or suggestions? Visit the `issue tracker <https://github.com/andras-tim/tchart/issues>`__.
